@@ -65,9 +65,14 @@ def create_knada_nb_pod_operator(
         "LOG_ENABLED": "true" if log_output else "false",
         "NOTEBOOK_PATH": f"{POD_WORKSPACE_DIR}/{Path(nb_path).parent}",
         "NOTEBOOK_NAME": Path(nb_path).name,
-        "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
-        "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
+        "DATAVERK_API_ENDPOINT": os.getenv("DATAVERK_API_ENDPOINT"),
+        "DATAVERK_BUCKET_ENDPOINT": os.getenv("DATAVERK_BUCKET_ENDPOINT"),
+        "DATAVERK_STORAGE_SINK": os.getenv("DATAVERK_STORAGE_SINK"),
+        "DATAVERK_ES_HOST": os.getenv("DATAVERK_ES_HOST"),
+        "DATAVERK_BUCKET": os.getenv("DATAVERK_BUCKET"),
         "DATAVERK_SECRETS_FROM_API": "true",
+        "DATAVERK_HOST": os.environ["DATAVERK_HOST"],
+        "DATAVERK_ENVIRONMENT": os.environ["DATAVERK_ENVIRONMENT"],
         "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
         "https_proxy": os.environ["HTTPS_PROXY"],
         "NO_PROXY": os.environ["NO_PROXY"],
@@ -186,9 +191,14 @@ def create_knada_python_pod_operator(
     env_vars = {
         "NOTEBOOK_PATH": f"{POD_WORKSPACE_DIR}/{Path(script_path).parent}",
         "NOTEBOOK_NAME": Path(script_path).name,
-        "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
-        "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
+        "DATAVERK_API_ENDPOINT": os.getenv("DATAVERK_API_ENDPOINT"),
+        "DATAVERK_BUCKET_ENDPOINT": os.getenv("DATAVERK_BUCKET_ENDPOINT"),
+        "DATAVERK_STORAGE_SINK": os.getenv("DATAVERK_STORAGE_SINK"),
+        "DATAVERK_ES_HOST": os.getenv("DATAVERK_ES_HOST"),
+        "DATAVERK_BUCKET": os.getenv("DATAVERK_BUCKET"),
         "DATAVERK_SECRETS_FROM_API": "true",
+        "DATAVERK_HOST": os.environ["DATAVERK_HOST"],
+        "DATAVERK_ENVIRONMENT": os.environ["DATAVERK_ENVIRONMENT"],
         "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
         "https_proxy": os.environ["HTTPS_PROXY"],
         "NO_PROXY": os.environ["NO_PROXY"],
